ConfigBuilder

Struct ConfigBuilder 

pub struct ConfigBuilder { /* private fields */ }
Builder, which allows to create a new Config

The first role added will be set as the default role. This can be changed by calling default_role with the role name.

Example

use terraphim_config::ConfigBuilder;

let config = ConfigBuilder::new()
   .global_shortcut("Ctrl+X")
   .with_role("Default", role)
   .with_role("Engineer", role)
   .with_role("System Operator", role)
   .default_role("Default")
   .build();

Implementations

Source

impl ConfigBuilder

pub fn new() -> Self

Create a new ConfigBuilder

pub fn new_with_id(id: ConfigId) -> Self

pub fn build_default_embedded(self) -> Self

pub fn get_default_data_path(&self) -> PathBuf

pub fn build_default_server(self) -> Self

pub fn build_default_desktop(self) -> Self

pub fn from_config( config: Config, device_settings: DeviceSettings, settings_path: PathBuf, ) -> Self

Start from an existing config

This is useful when you want to start from an setup and modify some fields

pub fn global_shortcut(self, global_shortcut: &str) -> Self

Set the global shortcut for the config

pub fn add_role(self, role_name: &str, role: Role) -> Self

Add a new role to the config

pub fn default_role(self, default_role: &str) -> Result<Self>

Set the default role for the config

pub fn build(self) -> Result<Config>

Build the config