pub struct KnowledgeGraphLocal {
pub input_type: KnowledgeGraphInputType,
pub path: PathBuf,
}Fields
input_type: KnowledgeGraphInputTypepath: PathBufTrait Implementations
Sourceimpl Clone for KnowledgeGraphLocal
impl Clone for KnowledgeGraphLocal
Sourcefn clone(&self) -> KnowledgeGraphLocal
fn clone(&self) -> KnowledgeGraphLocal
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for KnowledgeGraphLocal
impl Debug for KnowledgeGraphLocal
Sourceimpl<'de> Deserialize<'de> for KnowledgeGraphLocal
impl<'de> Deserialize<'de> for KnowledgeGraphLocal
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<KnowledgeGraphLocal> for JsValuewhere
KnowledgeGraphLocal: Serialize,
impl From<KnowledgeGraphLocal> for JsValuewhere
KnowledgeGraphLocal: Serialize,
Sourcefn from(value: KnowledgeGraphLocal) -> Self
fn from(value: KnowledgeGraphLocal) -> Self
Converts to this type from the input type.
Sourceimpl FromWasmAbi for KnowledgeGraphLocalwhere
Self: DeserializeOwned,
impl FromWasmAbi for KnowledgeGraphLocalwhere
Self: DeserializeOwned,
Sourceimpl IntoWasmAbi for &KnowledgeGraphLocalwhere
KnowledgeGraphLocal: Serialize,
impl IntoWasmAbi for &KnowledgeGraphLocalwhere
KnowledgeGraphLocal: Serialize,
Sourceimpl IntoWasmAbi for KnowledgeGraphLocalwhere
KnowledgeGraphLocal: Serialize,
impl IntoWasmAbi for KnowledgeGraphLocalwhere
KnowledgeGraphLocal: Serialize,
Sourceimpl JsonSchema for KnowledgeGraphLocal
impl JsonSchema for KnowledgeGraphLocal
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl OptionFromWasmAbi for KnowledgeGraphLocalwhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for KnowledgeGraphLocalwhere
Self: DeserializeOwned,
Sourceimpl OptionIntoWasmAbi for KnowledgeGraphLocalwhere
KnowledgeGraphLocal: Serialize,
impl OptionIntoWasmAbi for KnowledgeGraphLocalwhere
KnowledgeGraphLocal: Serialize,
Sourceimpl PartialEq for KnowledgeGraphLocal
impl PartialEq for KnowledgeGraphLocal
Sourceimpl RefFromWasmAbi for KnowledgeGraphLocalwhere
Self: DeserializeOwned,
impl RefFromWasmAbi for KnowledgeGraphLocalwhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourcetype Anchor = SelfOwner<KnowledgeGraphLocal>
type Anchor = SelfOwner<KnowledgeGraphLocal>
The type that holds the reference to
Self for the duration of the
invocation of the function that has an &Self parameter. This is
required to ensure that the lifetimes don’t persist beyond one function
call, and so that they remain anonymous.Sourceimpl Serialize for KnowledgeGraphLocal
impl Serialize for KnowledgeGraphLocal
Sourceimpl Tsify for KnowledgeGraphLocal
impl Tsify for KnowledgeGraphLocal
const DECL: &'static str = "export interface KnowledgeGraphLocal {\n input_type: KnowledgeGraphInputType;\n path: string;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl VectorFromWasmAbi for KnowledgeGraphLocalwhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for KnowledgeGraphLocalwhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl VectorIntoWasmAbi for KnowledgeGraphLocalwhere
KnowledgeGraphLocal: Serialize,
impl VectorIntoWasmAbi for KnowledgeGraphLocalwhere
KnowledgeGraphLocal: Serialize,
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi
Sourceimpl WasmDescribeVector for KnowledgeGraphLocal
impl WasmDescribeVector for KnowledgeGraphLocal
impl Eq for KnowledgeGraphLocal
impl StructuralPartialEq for KnowledgeGraphLocal